@@ -6,4 +6,5 @@ from threading import Lock
 TEST_PARAMETER_LOCK = Lock()
 
 api.add_resource(TestController, '/api/tests')
-api.add_resource(TestParameterController, '/api/parameters', kwargs={'lock_obj': TEST_PARAMETER_LOCK})
+api.add_resource(TestParameterController, '/api/parameters',
+                 resource_class_kwargs ={'lock_obj': TEST_PARAMETER_LOCK})
