@@ -7,4 +7,4 @@ class FITestParameterContext(Base):
     __tablename__ = 'test_parameter_context'
 
     id = Column(Integer, primary_key=True)
-    context_label = Column(String)
+    context_label = Column(Text(4000))
