@@ -1,4 +1,4 @@
-from wafec.fi.hypothesis.utils.wrapper import make_custom_wrapper_client
+from wafec.fi.hypothesis.utils import make_custom_wrapper_client
 
 import copy
 
