@@ -1,5 +1,5 @@
 from ._config import parameter_client_factory
-from .wrapper import Wrapper, make_wrapper, make_wrapper_simple_client
+from .wrapper import Wrapper, make_wrapper, make_wrapper_simple_client, make_custom_wrapper_client
 from .configuration import Default
 
 
@@ -8,5 +8,6 @@ __all__ = [
     'make_wrapper',
     'make_wrapper_simple_client',
     'Default',
-    'parameter_client_factory'
+    'parameter_client_factory',
+    'make_custom_wrapper_client'
 ]
